@@ -81,8 +81,8 @@ class CrsTransform(object):
         coords = []
         for i in range(len(crs_coords)):
             row = []
-            for j in range(len(crs_coords[0])):
-                vec = v3.VectorThree(crs_coords[i][j][0],crs_coords[i][j][1],0)
+            for j in range(len(crs_coords[0])):                
+                vec = crs_coords[i][j]
                 vec_t = self.crs_to_xyz(vec)
                 row.append(vec_t)
             coords.append(row)
@@ -93,7 +93,7 @@ class CrsTransform(object):
         for i in range(len(xyz_coords)):
             row = []
             for j in range(len(xyz_coords[0])):
-                vec = v3.VectorThree(xyz_coords[i][j][0],xyz_coords[i][j][1],0)
+                vec = xyz_coords[i][j]
                 vec_t = self.xyz_to_crs(vec)
                 row.append(vec_t)
             coords.append(row)
